%{?mingw_package_header}

%global pkgname libgeotiff

Name:      mingw-%{pkgname}
Version:   1.4.0
Release:   %mkrel 6
Summary:   MinGW Windows %{pkgname} library

Group:     Development/Other
License:   MIT
URL:       http://trac.osgeo.org/geotiff/
BuildArch: noarch
Source0:   http://download.osgeo.org/geotiff/%{pkgname}/%{pkgname}-%{version}.tar.gz
# - Add -no-undefined to linker flags
# - Fix include directory
# - Fix some configure.ac syntax issues
Patch0:    libgeotiff_buildsys.patch

BuildRequires: autoconf 
BuildRequires: automake 
BuildRequires: libtool

BuildRequires: mingw32-filesystem >= 95
BuildRequires: mingw32-gcc
BuildRequires: mingw32-binutils
BuildRequires: mingw32-libtiff
BuildRequires: mingw32-libjpeg
BuildRequires: mingw32-proj
BuildRequires: mingw32-zlib

BuildRequires: mingw64-filesystem >= 95
BuildRequires: mingw64-gcc
BuildRequires: mingw64-binutils
BuildRequires: mingw64-libtiff
BuildRequires: mingw64-libjpeg
BuildRequires: mingw64-proj
BuildRequires: mingw64-zlib


%description
%{summary}.


%package -n mingw32-%{pkgname}
Summary:       MinGW Windows %{pkgname} library

%description -n mingw32-%{pkgname}
%{summary}.


%package -n mingw32-%{pkgname}-static
Summary:       Static version of the MinGW Windows %{pkgname} library
Requires:      mingw32-%{pkgname} = %{version}-%{release}

%description -n mingw32-%{pkgname}-static
%{summary}.


%package -n mingw32-%{pkgname}-tools
Summary:       Tools for the MinGW Windows %{pkgname} library
Requires:      mingw32-%{pkgname} = %{version}-%{release}

%description -n mingw32-%{pkgname}-tools
%{summary}.


%package -n mingw64-%{pkgname}
Summary:       MinGW Windows %{pkgname} library

%description -n mingw64-%{pkgname}
%{summary}.


%package -n mingw64-%{pkgname}-static
Summary:       Static version of the MinGW Windows %{pkgname} library
Requires:      mingw64-%{pkgname} = %{version}-%{release}

%description -n mingw64-%{pkgname}-static
%{summary}.


%package -n mingw64-%{pkgname}-tools
Summary:       Tools for the MinGW Windows %{pkgname} library
Requires:      mingw64-%{pkgname} = %{version}-%{release}

%description -n mingw64-%{pkgname}-tools
%{summary}.


%{?mingw_debug_package}


%prep
%setup -q -n %{pkgname}-%{version}
%patch0 -p1

# fix wrongly encoded files from tarball
for f in $(find . -type f); do
   if file $f | grep -q ISO-8859 ; then
      iconv -f ISO-8859-1 -t UTF-8 $f > ${f}.tmp && \
         mv -f ${f}.tmp $f
   fi
   if file $f | grep -q CRLF ; then
      sed -i -e 's|\r$||g' $f
   fi
done


%build
autoreconf -if
%{mingw_configure} --with-proj --with-jpeg --with-zip
%{mingw_make} %{?_smp_mflags}

%install
%{mingw_make} install DESTDIR=%{buildroot}

# install pkgconfig files
mkdir -p %{buildroot}%{mingw32_libdir}/pkgconfig/
cat > %{buildroot}%{mingw32_libdir}/pkgconfig/%{pkgname}.pc <<EOF
prefix=%{mingw32_prefix}
exec_prefix=%{mingw32_prefix}
libdir=%{mingw32_libdir}
includedir=%{mingw32_includedir}/%{pkgname}

Name: %{pkgname}
Description: GeoTIFF file format library
Version: %{version}
Libs: -L${libdir} -lgeotiff
Cflags: -I${includedir}
EOF

mkdir -p %{buildroot}%{mingw64_libdir}/pkgconfig/
cat > %{buildroot}%{mingw64_libdir}/pkgconfig/%{pkgname}.pc <<EOF
prefix=%{mingw64_prefix}
exec_prefix=%{mingw64_prefix}
libdir=%{mingw64_libdir}
includedir=%{mingw64_includedir}/%{pkgname}

Name: %{pkgname}  
Description: GeoTIFF file format library
Version: %{version} 
Libs: -L${libdir} -lgeotiff
Cflags: -I${includedir}
EOF

# Remove static libraries
find %{buildroot} -name '*.la' -exec rm -f {} ';'


%files -n mingw32-%{pkgname}
%doc ChangeLog README
%license COPYING
%{mingw32_bindir}/libgeotiff-2.dll
%{mingw32_includedir}/*
%{mingw32_datadir}/*
%{mingw32_libdir}/libgeotiff.dll.a
%{mingw32_libdir}/pkgconfig/libgeotiff.pc

%files -n mingw32-%{pkgname}-static
%{mingw32_libdir}/libgeotiff.a

%files -n mingw32-%{pkgname}-tools
%{mingw32_bindir}/*.exe

%files -n mingw64-%{pkgname}
%doc ChangeLog README
%license COPYING
%{mingw64_bindir}/libgeotiff-2.dll
%{mingw64_includedir}/*
%{mingw64_datadir}/*
%{mingw64_libdir}/libgeotiff.dll.a
%{mingw64_libdir}/pkgconfig/libgeotiff.pc

%files -n mingw64-%{pkgname}-static
%{mingw64_libdir}/libgeotiff.a

%files -n mingw64-%{pkgname}-tools 
%{mingw64_bindir}/*.exe  




%changelog
* Wed May 11 2016 tv <tv> 1.4.0-6.mga6
+ Revision: 1012913
- rebuild for new mingw-proj

* Fri Feb 05 2016 umeabot <umeabot> 1.4.0-5.mga6
+ Revision: 938563
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.4.0-4.mga5
+ Revision: 741980
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.4.0-3.mga5
+ Revision: 682470
- Mageia 5 Mass Rebuild

* Mon Sep 23 2013 neoclust <neoclust> 1.4.0-2.mga4
+ Revision: 483961
- imported package mingw-libgeotiff

